==> delay_native0.4_3-0.4.7-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"delay","t":"delay","d":"","k":"static"},
{"l":"de/rmgk.html#","e":false,"i":"","n":"de.rmgk","t":"de.rmgk","d":"","k":"package"},
{"l":"de/rmgk/delay$.html#","e":false,"i":"","n":"delay","t":"delay","d":"de.rmgk","k":"object"},
{"l":"de/rmgk/delay$.html#Async-fffffd4a","e":false,"i":"","n":"Async","t":"Async[Ctx]: AsyncCompanion[Ctx]","d":"de.rmgk.delay","k":"def"},
{"l":"de/rmgk/delay$.html#Sync-fffff217","e":false,"i":"","n":"Sync","t":"Sync[Ctx]: SyncCompanion[Ctx]","d":"de.rmgk.delay","k":"def"},
{"l":"de/rmgk/delay$.html#extensions-0","e":false,"i":"","n":"extensions","t":"extensions: extensions.type","d":"de.rmgk.delay","k":"given"},
{"l":"de/rmgk/delay$$Async.html#","e":false,"i":"","n":"Async","t":"Async[-Ctx, +A](val handleInCtx: Ctx => Callback[A] => Unit)","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Async.html#bind-0","e":false,"i":"","n":"bind","t":"bind: A","d":"de.rmgk.delay.Async","k":"def"},
{"l":"de/rmgk/delay$$Async.html#handleInCtx-0","e":false,"i":"","n":"handleInCtx","t":"handleInCtx: Ctx => Callback[A] => Unit","d":"de.rmgk.delay.Async","k":"val"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#","e":false,"i":"","n":"AsyncCompanion","t":"AsyncCompanion[Ctx]","d":"de.rmgk.delay","k":"trait"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#apply-fffff271","e":false,"i":"","n":"apply","t":"apply[A](inline expr: Ctx ?=> A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#fromCallback-fffff271","e":false,"i":"","n":"fromCallback","t":"fromCallback[A](inline f: Ctx ?=> Callback[A] ?=> Unit): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#handler-471","e":false,"i":"","n":"handler","t":"handler[A](using cb: Callback[A]): Callback[A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#resource-c96","e":false,"i":"","n":"resource","t":"resource[R, A](inline open: R, inline close: R => Unit)(inline body: Ctx ?=> R => A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#syntax-fffff3f5","e":false,"i":"","n":"syntax","t":"syntax[A](inline expr: A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#","e":false,"i":"","n":"Callback","t":"Callback[-A]","d":"de.rmgk.delay","k":"trait"},
{"l":"de/rmgk/delay$$Callback.html#complete-fffff1e3","e":false,"i":"","n":"complete","t":"complete(tr: Try[A]): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#complete-5b5","e":false,"i":"","n":"complete","t":"complete(res: Either[Throwable, A]): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#fail-4b8","e":false,"i":"","n":"fail","t":"fail(ex: Throwable): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#succeed-fffff71f","e":false,"i":"","n":"succeed","t":"succeed(value: A): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#","e":false,"i":"","n":"DelayMacros","t":"DelayMacros","d":"de.rmgk.delay","k":"object"},
{"l":"de/rmgk/delay$$DelayMacros$.html#applyInBlock-a30","e":false,"i":"","n":"applyInBlock","t":"applyInBlock[Ctx : Type, B : Type](dio: Expr[Sync[Ctx, B]], ctx: Expr[Ctx])(implicit evidence$2: Type[Ctx], evidence$3: Type[B], quotes: Quotes): Expr[B]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#asyncImpl-b1f","e":false,"i":"","n":"asyncImpl","t":"asyncImpl[Ctx : Type, T : Type](expr: Expr[T])(implicit evidence$6: Type[Ctx], evidence$7: Type[T], quotes: Quotes): Expr[Async[Ctx, T]]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#cleanBlock-fffff38a","e":false,"i":"","n":"cleanBlock","t":"cleanBlock[A](using quotes: Quotes)(expr: Term): Term","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#handleInBlock-f3f","e":false,"i":"","n":"handleInBlock","t":"handleInBlock[Ctx : Type, B : Type](dio: Expr[Async[Ctx, B]], ctx: Expr[Ctx], cb: Expr[Callback[B]])(implicit evidence$4: Type[Ctx], evidence$5: Type[B], quotes: Quotes): Expr[Unit]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$$CleanBlock$.html#","e":false,"i":"","n":"CleanBlock","t":"CleanBlock","d":"de.rmgk.delay.DelayMacros","k":"object"},
{"l":"de/rmgk/delay$$DelayMacros$$CleanBlock$.html#unapply-884","e":false,"i":"","n":"unapply","t":"unapply(using quotes: Quotes)(expr: Term): Some[Term]","d":"de.rmgk.delay.DelayMacros.CleanBlock","k":"def"},
{"l":"de/rmgk/delay$$Promise.html#","e":false,"i":"","n":"Promise","t":"Promise[T] extends Callback[T]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Promise.html#async-0","e":false,"i":"","n":"async","t":"async: Async[Any, T]","d":"de.rmgk.delay.Promise","k":"val"},
{"l":"de/rmgk/delay$$Sync.html#","e":false,"i":"","n":"Sync","t":"Sync[-Ctx, +A](val runInContext: Ctx => A) extends Async[Ctx, A]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Sync.html#runInContext-0","e":false,"i":"","n":"runInContext","t":"runInContext: Ctx => A","d":"de.rmgk.delay.Sync","k":"val"},
{"l":"de/rmgk/delay$$SyncCompanion.html#","e":false,"i":"","n":"SyncCompanion","t":"SyncCompanion[Ctx]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$SyncCompanion.html#apply-806","e":false,"i":"","n":"apply","t":"apply[A](inline run: Ctx ?=> A): Sync[Ctx, A]","d":"de.rmgk.delay.SyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#","e":false,"i":"","n":"extensions","t":"extensions","d":"de.rmgk.delay","k":"object"},
{"l":"de/rmgk/delay$$extensions$.html#after-fffffbff","e":false,"i":"Async[Ctx, A]","n":"after","t":"after(inline body: Ctx ?=> Either[Throwable, A] => Unit): Async[Ctx, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#flatMap-fffffcb2","e":false,"i":"Sync[Ctx, A]","n":"flatMap","t":"flatMap[B](inline f: A => Sync[Ctx, B]): Sync[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#flatMap-fffff654","e":false,"i":"Async[Ctx, A]","n":"flatMap","t":"flatMap[B](inline f: A => Async[Ctx, B]): Async[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#map-fffffcb2","e":false,"i":"Sync[Ctx, A]","n":"map","t":"map[B](inline f: A => B): Sync[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#map-fffff654","e":false,"i":"Async[Ctx, A]","n":"map","t":"map[B](inline f: A => B): Async[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#run-7fa","e":false,"i":"Sync[Ctx, A]","n":"run","t":"run(using inline ctx: Ctx): A","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#run-48c","e":false,"i":"Async[Ctx, A]","n":"run","t":"run(inline cb: Callback[A])(using inline ctx: Ctx): Unit","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#runToAsync-c27","e":false,"i":"Async[Ctx, A]","n":"runToAsync","t":"runToAsync(using inline ctx: Ctx): Async[Ctx, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#runToFuture-fffff19c","e":false,"i":"Async[Ctx, A]","n":"runToFuture","t":"runToFuture(using inline ctx: Ctx): Future[A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#toAsync-16","e":false,"i":"Future[A]","n":"toAsync","t":"toAsync(using inline ec: ExecutionContext): Async[Any, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#toAsync-8ae","e":false,"i":"CompletionStage[T]","n":"toAsync","t":"toAsync: Async[Ctx, T]","d":"de.rmgk.delay.extensions","k":"def"}];

==> delay_native0.4_3-0.4.8-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"delay","t":"delay","d":"","k":"static"},
{"l":"de/rmgk.html#","e":false,"i":"","n":"de.rmgk","t":"de.rmgk","d":"","k":"package"},
{"l":"de/rmgk/delay$.html#","e":false,"i":"","n":"delay","t":"delay","d":"de.rmgk","k":"object"},
{"l":"de/rmgk/delay$.html#Async-fffffd4a","e":false,"i":"","n":"Async","t":"Async[Ctx]: AsyncCompanion[Ctx]","d":"de.rmgk.delay","k":"def"},
{"l":"de/rmgk/delay$.html#Sync-fffff217","e":false,"i":"","n":"Sync","t":"Sync[Ctx]: SyncCompanion[Ctx]","d":"de.rmgk.delay","k":"def"},
{"l":"de/rmgk/delay$$Async.html#","e":false,"i":"","n":"Async","t":"Async[-Ctx, +A](val handleInCtx: Ctx => Callback[A] => Unit)","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Async.html#bind-0","e":false,"i":"","n":"bind","t":"bind: A","d":"de.rmgk.delay.Async","k":"def"},
{"l":"de/rmgk/delay$$Async.html#handleInCtx-0","e":false,"i":"","n":"handleInCtx","t":"handleInCtx: Ctx => Callback[A] => Unit","d":"de.rmgk.delay.Async","k":"val"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#","e":false,"i":"","n":"AsyncCompanion","t":"AsyncCompanion[Ctx]","d":"de.rmgk.delay","k":"trait"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#apply-fffff271","e":false,"i":"","n":"apply","t":"apply[A](inline expr: Ctx ?=> A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#fromCallback-fffff271","e":false,"i":"","n":"fromCallback","t":"fromCallback[A](inline f: Ctx ?=> Callback[A] ?=> Unit): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#handler-471","e":false,"i":"","n":"handler","t":"handler[A](using cb: Callback[A]): Callback[A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#provided-fffff45d","e":false,"i":"","n":"provided","t":"provided[Ctx, A](ctx: Ctx)(inline expr: Ctx ?=> A): Async[Any, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#resource-c96","e":false,"i":"","n":"resource","t":"resource[R, A](inline open: R, inline close: R => Unit)(inline body: Ctx ?=> R => A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$AsyncCompanion.html#syntax-fffff3f5","e":false,"i":"","n":"syntax","t":"syntax[A](inline expr: A): Async[Ctx, A]","d":"de.rmgk.delay.AsyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#","e":false,"i":"","n":"Callback","t":"Callback[-A]","d":"de.rmgk.delay","k":"trait"},
{"l":"de/rmgk/delay$$Callback.html#complete-fffff1e3","e":false,"i":"","n":"complete","t":"complete(tr: Try[A]): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#complete-5b5","e":false,"i":"","n":"complete","t":"complete(res: Either[Throwable, A]): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#fail-4b8","e":false,"i":"","n":"fail","t":"fail(ex: Throwable): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$Callback.html#succeed-fffff71f","e":false,"i":"","n":"succeed","t":"succeed(value: A): Unit","d":"de.rmgk.delay.Callback","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#","e":false,"i":"","n":"DelayMacros","t":"DelayMacros","d":"de.rmgk.delay","k":"object"},
{"l":"de/rmgk/delay$$DelayMacros$.html#applyInBlock-a30","e":false,"i":"","n":"applyInBlock","t":"applyInBlock[Ctx : Type, B : Type](dio: Expr[Sync[Ctx, B]], ctx: Expr[Ctx])(implicit evidence$2: Type[Ctx], evidence$3: Type[B], quotes: Quotes): Expr[B]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#asyncImpl-b1f","e":false,"i":"","n":"asyncImpl","t":"asyncImpl[Ctx : Type, T : Type](expr: Expr[T])(implicit evidence$6: Type[Ctx], evidence$7: Type[T], quotes: Quotes): Expr[Async[Ctx, T]]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#cleanBlock-fffff38a","e":false,"i":"","n":"cleanBlock","t":"cleanBlock[A](using quotes: Quotes)(expr: Term): Term","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$.html#handleInBlock-f3f","e":false,"i":"","n":"handleInBlock","t":"handleInBlock[Ctx : Type, B : Type](dio: Expr[Async[Ctx, B]], ctx: Expr[Ctx], cb: Expr[Callback[B]])(implicit evidence$4: Type[Ctx], evidence$5: Type[B], quotes: Quotes): Expr[Unit]","d":"de.rmgk.delay.DelayMacros","k":"def"},
{"l":"de/rmgk/delay$$DelayMacros$$CleanBlock$.html#","e":false,"i":"","n":"CleanBlock","t":"CleanBlock","d":"de.rmgk.delay.DelayMacros","k":"object"},
{"l":"de/rmgk/delay$$DelayMacros$$CleanBlock$.html#unapply-884","e":false,"i":"","n":"unapply","t":"unapply(using quotes: Quotes)(expr: Term): Some[Term]","d":"de.rmgk.delay.DelayMacros.CleanBlock","k":"def"},
{"l":"de/rmgk/delay$$Promise.html#","e":false,"i":"","n":"Promise","t":"Promise[T] extends Callback[T]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Promise.html#async-0","e":false,"i":"","n":"async","t":"async: Async[Any, T]","d":"de.rmgk.delay.Promise","k":"val"},
{"l":"de/rmgk/delay$$Sync.html#","e":false,"i":"","n":"Sync","t":"Sync[-Ctx, +A](val runInContext: Ctx => A) extends Async[Ctx, A]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$Sync.html#runInContext-0","e":false,"i":"","n":"runInContext","t":"runInContext: Ctx => A","d":"de.rmgk.delay.Sync","k":"val"},
{"l":"de/rmgk/delay$$SyncCompanion.html#","e":false,"i":"","n":"SyncCompanion","t":"SyncCompanion[Ctx]","d":"de.rmgk.delay","k":"class"},
{"l":"de/rmgk/delay$$SyncCompanion.html#apply-806","e":false,"i":"","n":"apply","t":"apply[A](inline run: Ctx ?=> A): Sync[Ctx, A]","d":"de.rmgk.delay.SyncCompanion","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#","e":false,"i":"","n":"extensions","t":"extensions","d":"de.rmgk.delay","k":"object"},
{"l":"de/rmgk/delay$$extensions$.html#flatMap-fffffcb2","e":false,"i":"Sync[Ctx, A]","n":"flatMap","t":"flatMap[B](inline f: A => Sync[Ctx, B]): Sync[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#flatMap-fffff654","e":false,"i":"Async[Ctx, A]","n":"flatMap","t":"flatMap[B](inline f: Ctx ?=> A => Async[Ctx, B]): Async[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#map-fffffcb2","e":false,"i":"Sync[Ctx, A]","n":"map","t":"map[B](inline f: A => B): Sync[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#map-fffff654","e":false,"i":"Async[Ctx, A]","n":"map","t":"map[B](inline f: Ctx ?=> A => B): Async[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#provide-fffff654","e":false,"i":"Async[Ctx, A]","n":"provide","t":"provide[Outer](inline part: Outer ?=> Ctx): Async[Outer, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#recover-fffffbff","e":false,"i":"Async[Ctx, A]","n":"recover","t":"recover(inline f: Ctx ?=> Throwable => Async[Ctx, A]): Async[Ctx, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#run-7fa","e":false,"i":"Sync[Ctx, A]","n":"run","t":"run(using inline ctx: Ctx): A","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#run-fffffb86","e":false,"i":"Async[Ctx, A]","n":"run","t":"run(using inline ctx: Ctx)(inline cb: Callback[A]): Unit","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#runToAsync-c27","e":false,"i":"Async[Ctx, A]","n":"runToAsync","t":"runToAsync(using inline ctx: Ctx): Async[Ctx, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#runToFuture-fffff19c","e":false,"i":"Async[Ctx, A]","n":"runToFuture","t":"runToFuture(using inline ctx: Ctx): Future[A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#toAsync-16","e":false,"i":"Future[A]","n":"toAsync","t":"toAsync(using inline ec: ExecutionContext): Async[Any, A]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#toAsync-ffffffad","e":false,"i":"CompletionStage[T]","n":"toAsync","t":"toAsync: Async[Any, T]","d":"de.rmgk.delay.extensions","k":"def"},
{"l":"de/rmgk/delay$$extensions$.html#transform-fffff654","e":false,"i":"Async[Ctx, A]","n":"transform","t":"transform[B](inline f: Ctx ?=> Try[A] => Async[Ctx, B]): Async[Ctx, B]","d":"de.rmgk.delay.extensions","k":"def"}];
